# buyback-toolkit
 A Python toolkit for simulating and analyzing share buyback strategies

[![Build](https://github.com/Switzerland-MQP-C24/buyback-toolkit/actions/workflows/python-package.yml/badge.svg)](https://github.com/Switzerland-MQP-C24/buyback-toolkit/actions/workflows/python-package.yml)
![PyPI - Version](https://img.shields.io/pypi/v/buyback)
![PyPI - Python Version](https://img.shields.io/pypi/pyversions/buyback)
